# Orthophoto segmentation

This project provides a procedure and (python) scripts to make it (relatively) easy to 
1. create a training dataset for a topic of your choice
2. train a neural network to segment orthophotos
3. apply the segmentation on a larger area + vectorize the result

Only open source software is needed, eg. QGIS and tensorflow.

Installation and usage instructions can be found in the [orthoseg wiki](https://github.com/orthoseg/orthoseg/wiki)
